==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/nn-NO/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tilbehør sjekket inn',
    'Accessory_Checkout_Notification' => 'Tilbehør sjekket ut',
    'Asset_Checkin_Notification' => 'Eiendel sjekket inn',
    'Asset_Checkout_Notification' => 'Ressurs sjekket ut',
    'Confirm_Accessory_Checkin' => 'Bekreft innsjekk av tilbehør',
    'Confirm_Asset_Checkin' => 'Bekreft innsjekk av eiendel',
    'Confirm_accessory_delivery' => 'Bekreft levering av tilbehør',
    'Confirm_asset_delivery' => 'Bekreft levering av eiendel',
    'Confirm_consumable_delivery' => 'Bekreft levering av forbruksvare',
    'Confirm_license_delivery' => 'Bekreft levering av lisens',
    'Consumable_checkout_notification' => 'Forbruksvaren tatt ut',
    'Days' => 'Dager',
    'Expected_Checkin_Date' => 'En enhet som er sjekket ut til deg skal leveres tilbake den :date',
    'Expected_Checkin_Notification' => 'Påminnelse: Innsjekkingsfrist for :name nærmer seg',
    'Expected_Checkin_Report' => 'Rapport over forventet innsjekking av eiendeler',
    'Expiring_Assets_Report' => 'Rapport utløpende eiendeler.',
    'Expiring_Licenses_Report' => 'Rapport utløpende lisenser.',
    'Item_Request_Canceled' => 'Forespørsel av enhet avbrutt',
    'Item_Requested' => 'Forespurt enhet',
    'License_Checkin_Notification' => 'Lisens sjekket inn',
    'License_Checkout_Notification' => 'Lisens sjekket ut',
    'Low_Inventory_Report' => 'Rapport lav lagerbeholdning',
    'a_user_canceled' => 'Brukeren har avbrutt en element-forespørsel på webområdet',
    'a_user_requested' => 'En bruker har bedt om et element på webområdet',
    'acceptance_asset_accepted' => 'En bruker har godtatt et element',
    'acceptance_asset_declined' => 'En bruker har avvist et element',
    'accessory_name' => 'Navn tilbehør',
    'additional_notes' => 'Flere notater',
    'admin_has_created' => 'En administrator har opprettet en konto for deg på :web nettsted.',
    'asset' => 'Eiendel',
    'asset_name' => 'Navn',
    'asset_requested' => 'Eiendel forespurt',
    'asset_tag' => 'Eiendelsmerke',
    'assets_warrantee_alert' => 'En eiendel har garanti som utløper innenfor de neste :treshold dagene.|:count eiendeler har garanti som utløper innenfor de neste :tershold dagene.',
    'assigned_to' => 'Tilordnet til',
    'best_regards' => 'Med vennlig hilsen,',
    'canceled' => 'Avbrutt',
    'checkin_date' => 'Innsjekkdato',
    'checkout_date' => 'Utsjekkdato',
    'checkedout_from' => 'Sjekket ut fra',
    'checkedin_from'  => 'Sjekket inn fra',
    'checked_into' => 'Sjekket inn',
    'click_on_the_link_accessory' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt tilbehøret.',
    'click_on_the_link_asset' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt eiendelen.',
    'click_to_confirm' => 'Klikk på følgende link for å bekrefte din :web konto:',
    'current_QTY' => 'Nåværende antall',
    'days' => 'Dager',
    'expecting_checkin_date' => 'Forventet dato for innsjekk',
    'expires' => 'Utløper',
    'hello' => 'Hallo',
    'hi' => 'Hei',
    'i_have_read' => 'Jeg har lest og godtar vilkårene for bruk, og har mottatt denne enheten.',
    'inventory_report' => 'Lagerbeholdnings rapport',
    'item' => 'Enhet',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => ':count lisens utløper de neste :threshold dagene.|:count lisenser utløper de neste :threshold dagene.',
    'link_to_update_password' => 'Klikk på følgende link for å bekrefte din :web passord:',
    'login' => 'Logg inn:',
    'login_first_admin' => 'Logg inn på din nye Snipe-IT-installasjon ved å bruke kontoen nedenfor:',
    'low_inventory_alert' => ':count enhet er under minimumnivå for beholdning, eller vil snart nå dette nivået.|:count enheter er under minimumnivå for beholdning, eller vil snart nå dette nivået.',
    'min_QTY' => 'Min. antall',
    'name' => 'Navn',
    'new_item_checked' => 'En ny enhet har blitt sjekket ut under ditt navn, detaljer nedenfor.',
    'notes' => 'Notater',
    'password' => 'Passord',
    'password_reset' => 'Tilbakestill passord',
    'read_the_terms' => 'Vennligst les bruksbetingelsene nedenfor.',
    'read_the_terms_and_click' => 'Vennligst les vilkårene for bruk nedenfor. og klikk på lenken nederst for å bekrefte at du leser og godtar vilkårene for bruk, og har mottatt eiendelen.',
    'requested' => 'Forespurt',
    'reset_link' => 'Lenke for tilbakestilling av passord',
    'reset_password' => 'Klikk her for å tilbakestille passordet:',
    'rights_reserved' => 'Alle rettigheter forbeholdt.',
    'serial' => 'Serienummer',
    'snipe_webhook_test' => 'Snipe-IT integrasjonstest',
    'snipe_webhook_summary' => 'Snipe-IT integrasjon test sammendrag',
    'supplier' => 'Leverandør',
    'tag' => 'Merke',
    'test_email' => 'Test-epost fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT eiendelsadministrasjonssystem. Hvis du mottok denne meldingen fungerer e-post.',
    'the_following_item' => 'Følgende enheter har blitt sjekket inn: ',
    'to_reset' => 'Fullfør dette skjemaet for å tilbakestille ditt :web passord:',
    'type' => 'Type',
    'upcoming-audits' => ':count eiendel har revisjonsfrist innen :treshold dager.|:count eiendeler har revisjonsfrist innen :threshold dager.',
    'user' => 'Bruker',
    'username' => 'Brukernavn',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Velkommen :name',
    'welcome_to' => 'Velkommen til :web!',
    'your_assets' => 'Vis dine eiendeler',
    'your_credentials' => 'Din Snipe-IT konto',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/nn-NO/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tilbehør sjekket inn',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'Bekreft innsjekk av tilbehør',
    'Confirm_Asset_Checkin' => 'Bekreft innsjekk av eiendel',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'Bekreft levering av tilbehør',
    'Confirm_asset_delivery' => 'Bekreft levering av eiendel',
    'Confirm_consumable_delivery' => 'Bekreft levering av forbruksvare',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'Bekreft levering av lisens',
    'Consumable_checkout_notification' => 'Forbruksvaren tatt ut',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'Dager',
    'Expected_Checkin_Date' => 'En enhet som er sjekket ut til deg skal leveres tilbake den :date',
    'Expected_Checkin_Notification' => 'Påminnelse: Innsjekkingsfrist for :name nærmer seg',
    'Expected_Checkin_Report' => 'Rapport over forventet innsjekking av eiendeler',
    'Expiring_Assets_Report' => 'Rapport utløpende eiendeler',
    'Expiring_Licenses_Report' => 'Rapport utløpende lisenser',
    'Item_Request_Canceled' => 'Forespørsel av enhet avbrutt',
    'Item_Requested' => 'Forespurt enhet',
    'License_Checkin_Notification' => 'Lisens sjekket inn',
    'License_Checkout_Notification' => 'Lisens sjekket ut',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Rapport lav lagerbeholdning',
    'a_user_canceled' => 'Brukeren har avbrutt en element-forespørsel på webområdet',
    'a_user_requested' => 'En bruker har bedt om et element på webområdet',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'En bruker har godtatt et element',
    'acceptance_asset_declined' => 'En bruker har avvist et element',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'Navn tilbehør',
    'additional_notes' => 'Flere notater',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'Eiendel',
    'asset_name' => 'Navn',
    'asset_requested' => 'Eiendel forespurt',
    'asset_tag' => 'Eiendelsmerke',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'Tilordnet til',
    'eol' => 'Levetid',
    'best_regards' => 'Med vennlig hilsen,',
    'canceled' => 'Avbrutt',
    'checkin_date' => 'Innsjekkdato',
    'checkout_date' => 'Utsjekkdato',
    'checkedout_from' => 'Sjekket ut fra',
    'checkedin_from'  => 'Sjekket inn fra',
    'checked_into' => 'Sjekket inn',
    'click_on_the_link_accessory' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt tilbehøret.',
    'click_on_the_link_asset' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt eiendelen.',
    'click_to_confirm' => 'Klikk på følgende link for å bekrefte din :web konto:',
    'current_QTY' => 'Nåværende antall',
    'days' => 'Dager',
    'expecting_checkin_date' => 'Forventet dato for innsjekk',
    'expires' => 'Utløper',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'Hallo',
    'hi' => 'Hei',
    'i_have_read' => 'Jeg har lest og godtar vilkårene for bruk, og har mottatt denne enheten.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Lagerbeholdnings rapport',
    'item' => 'Enhet',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'Klikk på følgende link for å bekrefte din :web passord:',
    'login' => 'Logg inn',
    'login_first_admin' => 'Logg inn på din nye Snipe-IT-installasjon ved å bruke kontoen nedenfor:',
    'low_inventory_alert' => ':count enhet er under minimumnivå for beholdning, eller vil snart nå dette nivået.|:count enheter er under minimumnivå for beholdning, eller vil snart nå dette nivået.',
    'min_QTY' => 'Min. antall',
    'name' => 'Navn',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'An item was recently checked out under your name that requires acceptance, details are below.',
    'notes' => 'Notater',
    'password' => 'Passord',
    'password_reset' => 'Tilbakestill passord',
    'read_the_terms' => 'Vennligst les bruksbetingelsene nedenfor.',
    'read_the_terms_and_click' => 'Vennligst les vilkårene for bruk nedenfor. og klikk på lenken nederst for å bekrefte at du leser og godtar vilkårene for bruk, og har mottatt eiendelen.',
    'requested' => 'Forespurt',
    'reset_link' => 'Lenke for tilbakestilling av passord',
    'reset_password' => 'Klikk her for å tilbakestille passordet:',
    'rights_reserved' => 'Alle rettigheter forbeholdt.',
    'serial' => 'Serienummer',
    'snipe_webhook_test' => 'Snipe-IT integrasjonstest',
    'snipe_webhook_summary' => 'Snipe-IT integrasjon test sammendrag',
    'supplier' => 'Leverandør',
    'tag' => 'Merke',
    'test_email' => 'Test-epost fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT eiendelsadministrasjonssystem. Hvis du mottok denne meldingen fungerer e-post.',
    'the_following_item' => 'Følgende enheter har blitt sjekket inn: ',
    'to_reset' => 'Fullfør dette skjemaet for å tilbakestille ditt :web passord:',
    'type' => 'Type',
    'upcoming-audits' => ':count eiendel har revisjonsfrist innen :treshold dager.|:count eiendeler har revisjonsfrist innen :threshold dager.',
    'user' => 'Bruker',
    'username' => 'Brukernavn',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'Velkommen :name',
    'welcome_to' => 'Velkommen til :web!',
    'your_assets' => 'Vis dine eiendeler',
    'your_credentials' => 'Din Snipe-IT konto',
    'mail_sent' => 'Mail sent successfully!',
];
